﻿//===========================================================================//
//                                                                           //
//  Copyright (C) 2004 - 2018                                                //
//  IDS Imaging GmbH                                                         //
//  Dimbacherstr. 6-8                                                        //
//  D-74182 Obersulm-Willsbach                                               //
//                                                                           //
//  The information in this document is subject to change without            //
//  notice and should not be construed as a commitment by IDS Imaging GmbH.  //
//  IDS Imaging GmbH does not assume any responsibility for any errors       //
//  that may appear in this document.                                        //
//                                                                           //
//  This document, or source code, is provided solely as an example          //
//  of how to utilize IDS software libraries in a sample application.        //
//  IDS Imaging GmbH does not assume any responsibility for the use or       //
//  reliability of any portion of this document or the described software.   //
//                                                                           //
//  General permission to copy or modify, but not for profit, is hereby      //
//  granted,  provided that the above copyright notice is included and       //
//  reference made to the fact that reproduction privileges were granted	 //
//	by IDS Imaging GmbH.				                                     //
//                                                                           //
//  IDS cannot assume any responsibility for the use or misuse of any        //
//  portion of this software for other than its intended diagnostic purpose	 //
//  in calibrating and testing IDS manufactured cameras and software.		 //
//                                                                           //
//===========================================================================//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Threading;

namespace uEyeImageQueue
{
    public partial class uEyeImageQueue : Form
    {
        // acquire thread
        public WorkerAcquire workerAcquireObject;
        public Thread workerAcquireThread;

        public uEyeImageQueue()
        {
            InitializeComponent();
        }

        private void uEyeImageQueue_Load(object sender, EventArgs e)
        {

            // our camera
            Globals.Camera = new uEye.Camera();

            // remeber the display handle
            Globals.displayHandle = pictureBoxDisplay.Handle;

            // Create thread for image acquisiition and start it
            workerAcquireObject = new WorkerAcquire();
            workerAcquireThread = new Thread(workerAcquireObject.DoWork);
            workerAcquireThread.Start();


            // open Camera
            uEye.Defines.Status statusRet = 0;
            statusRet = Globals.Camera.Init();
            if (statusRet != uEye.Defines.Status.Success)
            {
                MessageBox.Show("Camera initializing failed");
                Environment.Exit(-1);
            }


            //GUI
            uEye.Types.SensorInfo sensorInfo;
            Globals.Camera.Information.GetSensorInfo(out sensorInfo);
            textBoxModel.Text = sensorInfo.SensorName;


            // allocate inages buffers for 1 second of image queue
            double fFrameRate;
            Globals.Camera.Timing.Framerate.Get(out fFrameRate);
            int nNumberOfBuffers = (int)(fFrameRate);
            for (int i = 0; i < nNumberOfBuffers; i++)
            {
                int s32MemID;
                statusRet = Globals.Camera.Memory.Allocate(out s32MemID, false);
                if (statusRet == uEye.Defines.Status.Success)
                {
                    Globals.Camera.Memory.Sequence.Add(s32MemID);
                }
                else
                {
                    // exit, buffes are freed automatically
                    MessageBox.Show("Allocate Memory failed");
                    Environment.Exit(-1);
                }
            }
            statusRet = Globals.Camera.Memory.Sequence.InitImageQueue();


            // start live video
            statusRet = Globals.Camera.Acquisition.Capture();
            if (statusRet != uEye.Defines.Status.Success)
            {
                MessageBox.Show("Start Live Video failed");
            }
            else
            {
                Globals.bLive = true;
            }


        }

        private void TerminateApp()
        {
            // request that the worker thread stop itself:
            workerAcquireObject.RequestStopAcquire();
            // use the Join method to block the current thread 
            // until the object's thread terminates.
            workerAcquireThread.Join();

            // close the Camera
            Globals.Camera.Exit();
            Close();
        }


        private void buttonExit_Click(object sender, EventArgs e)
        {
            TerminateApp();
        }


    }
}
